MagicString

Struct MagicString 

pub struct MagicString<'s> { /* private fields */ }

Implementations

Source

impl<'text> MagicString<'text>

pub fn append(&mut self, source: impl Into<Cow<'text, str>>) -> &mut Self

pub fn append_left( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self

Example
 use string_wizard::MagicString;
 let mut s = MagicString::new("01234");
 s.append_left(2, "a");
 s.append_left(2, "b");
 assert_eq!(s.to_string(), "01ab234")
pub fn append_right( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self

Example
use string_wizard::MagicString;
let mut s = MagicString::new("01234");
s.append_right(2, "A");
s.append_right(2, "B");
s.append_left(2, "a");
s.append_left(2, "b");
assert_eq!(s.to_string(), "01abAB234")
Source

impl MagicString<'_>

pub fn indent(&mut self) -> &mut Self

pub fn indent_with(&mut self, opts: IndentOptions<'_, '_>) -> &mut Self

Source

impl MagicString<'_>

pub fn remove(&mut self, start: usize, end: usize) -> Result<&mut Self, String>

pub fn relocate( &mut self, start: usize, end: usize, to: usize, ) -> Result<&mut Self, String>

Moves the characters from start and end to index. Returns this.

pub fn snip(&self, start: usize, end: usize) -> Result<Self, String>

Returns a clone with content outside the specified range removed. This is equivalent to clone().remove(0, start).remove(end, original.len()).

Source

impl<'text> MagicString<'text>

pub fn prepend(&mut self, source: impl Into<Cow<'text, str>>) -> &mut Self

pub fn prepend_left( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self

pub fn prepend_right( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self

Source

impl<'text> MagicString<'text>

pub fn replace( &mut self, from: &str, to: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>

pub fn replace_all( &mut self, from: &str, to: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>

pub fn replace_with( &mut self, from: &str, to: impl Into<Cow<'text, str>>, options: ReplaceOptions, ) -> Result<&mut Self, String>

Source

impl<'text> MagicString<'text>

pub fn reset(&mut self, start: usize, end: usize) -> Result<&mut Self, String>

Resets the portion of the string from start to end to its original content. This undoes any modifications (updates, overwrites, intro/outro additions) made to that range.

Errors
  • If start is greater than to end
  • If the range is out of bounds
Source

impl<'text> MagicString<'text>

pub fn slice(&self, start: usize, end: Option<usize>) -> Result<String, String>

Returns the content of the generated string that corresponds to the original positions from start to end.

If end is None, it defaults to the original string length.

Source

impl MagicString<'_>

Source

impl<'text> MagicString<'text>

pub fn trim(&mut self, char_type: Option<&str>) -> &mut Self

Trims whitespace from the start and end of the string.

pub fn trim_start(&mut self, char_type: Option<&str>) -> &mut Self

Trims whitespace from the start of the string.

pub fn trim_end(&mut self, char_type: Option<&str>) -> &mut Self

Trims whitespace from the end of the string.

pub fn trim_lines(&mut self) -> &mut Self

Trims newlines from the start and end of the string.

Source

impl<'text> MagicString<'text>

pub fn update( &mut self, start: usize, end: usize, content: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>

A shorthand for update_with(start, end, content, Default::default());

pub fn update_with( &mut self, start: usize, end: usize, content: impl Into<Cow<'text, str>>, opts: UpdateOptions, ) -> Result<&mut Self, String>

Source

impl<'text> MagicString<'text>

pub fn new(source: impl Into<Cow<'text, str>>) -> Self

pub fn with_options( source: impl Into<Cow<'text, str>>, options: MagicStringOptions, ) -> Self

pub fn source(&self) -> &str

pub fn filename(&self) -> Option<&str>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn has_changed(&self) -> bool

Indicates if the string has been changed.

pub fn last_char(&self) -> Option<char>

Returns the last character of the generated string, or None if empty.

pub fn last_line(&self) -> String

Returns the content after the last newline in the generated string.