pub struct MagicString<'s> { /* private fields */ }Implementations
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
pub fn append(&mut self, source: impl Into<Cow<'text, str>>) -> &mut Self
Sourcepub fn append_left(
&mut self,
text_index: usize,
content: impl Into<Cow<'text, str>>,
) -> &mut Self
pub fn append_left( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self
Example
use string_wizard::MagicString;
let mut s = MagicString::new("01234");
s.append_left(2, "a");
s.append_left(2, "b");
assert_eq!(s.to_string(), "01ab234")Sourcepub fn append_right(
&mut self,
text_index: usize,
content: impl Into<Cow<'text, str>>,
) -> &mut Self
pub fn append_right( &mut self, text_index: usize, content: impl Into<Cow<'text, str>>, ) -> &mut Self
Example
use string_wizard::MagicString;
let mut s = MagicString::new("01234");
s.append_right(2, "A");
s.append_right(2, "B");
s.append_left(2, "a");
s.append_left(2, "b");
assert_eq!(s.to_string(), "01abAB234")Sourceimpl MagicString<'_>
impl MagicString<'_>
pub fn indent(&mut self) -> &mut Self
pub fn indent_with(&mut self, opts: IndentOptions<'_, '_>) -> &mut Self
Sourceimpl MagicString<'_>
impl MagicString<'_>
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
pub fn replace( &mut self, from: &str, to: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>
pub fn replace_all( &mut self, from: &str, to: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>
pub fn replace_with( &mut self, from: &str, to: impl Into<Cow<'text, str>>, options: ReplaceOptions, ) -> Result<&mut Self, String>
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
Sourcepub fn reset(&mut self, start: usize, end: usize) -> Result<&mut Self, String>
pub fn reset(&mut self, start: usize, end: usize) -> Result<&mut Self, String>
Resets the portion of the string from start to end to its original content.
This undoes any modifications (updates, overwrites, intro/outro additions) made to that range.
Errors
- If
startis greater than toend - If the range is out of bounds
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
Sourceimpl MagicString<'_>
impl MagicString<'_>
pub fn source_map(&self, opts: SourceMapOptions) -> SourceMap
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
Sourcepub fn trim(&mut self, char_type: Option<&str>) -> &mut Self
pub fn trim(&mut self, char_type: Option<&str>) -> &mut Self
Trims whitespace from the start and end of the string.
Sourcepub fn trim_start(&mut self, char_type: Option<&str>) -> &mut Self
pub fn trim_start(&mut self, char_type: Option<&str>) -> &mut Self
Trims whitespace from the start of the string.
Sourcepub fn trim_end(&mut self, char_type: Option<&str>) -> &mut Self
pub fn trim_end(&mut self, char_type: Option<&str>) -> &mut Self
Trims whitespace from the end of the string.
Sourcepub fn trim_lines(&mut self) -> &mut Self
pub fn trim_lines(&mut self) -> &mut Self
Trims newlines from the start and end of the string.
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
Sourcepub fn update(
&mut self,
start: usize,
end: usize,
content: impl Into<Cow<'text, str>>,
) -> Result<&mut Self, String>
pub fn update( &mut self, start: usize, end: usize, content: impl Into<Cow<'text, str>>, ) -> Result<&mut Self, String>
A shorthand for update_with(start, end, content, Default::default());
pub fn update_with( &mut self, start: usize, end: usize, content: impl Into<Cow<'text, str>>, opts: UpdateOptions, ) -> Result<&mut Self, String>
Sourceimpl<'text> MagicString<'text>
impl<'text> MagicString<'text>
pub fn new(source: impl Into<Cow<'text, str>>) -> Self
pub fn with_options( source: impl Into<Cow<'text, str>>, options: MagicStringOptions, ) -> Self
pub fn source(&self) -> &str
pub fn filename(&self) -> Option<&str>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn has_changed(&self) -> bool
pub fn has_changed(&self) -> bool
Indicates if the string has been changed.